@@ -3,13 +3,12 @@
 /* All rights reserved                                                     */
 /*                                                                         */
 /* Use of the link grammar parsing system is subject to the terms of the   */
-/* license set forth in the LICENSE file included with this software,      */
-/* and also available at http://www.link.cs.cmu.edu/link/license.html      */
+/* license set forth in the LICENSE file included with this software.      */
 /* This license allows free redistribution and use in source and binary    */
 /* forms, with or without modification, subject to certain conditions.     */
 /*                                                                         */
 /***************************************************************************/
 
 #ifdef HAVE_EDITLINE
-char *lg_readline(const char *mb_prompt);
+char *lg_readline(const char *, bool);
 #endif /* HAVE_EDITLINE */
